@@ -26,15 +26,15 @@ void mk_tempfile(stralloc *tmpf) {
   taia_tai(&now,&sec);
 
   /* Record the second timestamp on the string. */
-  secbuf[fmt_ulong(secbuf,sec.x)] = '\0';
+  secbuf[fmt_uint64(secbuf,(uint64) sec.x - 4611686018427387904)] = '\0';
   if (!stralloc_cats(tmpf, secbuf)) die_nomem();
   if (!stralloc_append(tmpf, ".")) die_nomem();
   
-  /* Record the microsecond timestamp + PID on the string. */
+  /* Record the millisecond timestamp + PID on the string. */
   taia_fmtfrac(atto,&now);
   atto[b--] = '\0';
-  for(; b>4; pid /= 10) {
-    atto[b--] = (char) ((pid % 10) + 48);
+  for(; b>5 || pid>0; pid /= 10) {
+    atto[b--] = (char) ((pid % 10) + '0');
   }
   if (!stralloc_cats(tmpf, atto)) die_nomem();
   if (!stralloc_append(tmpf, ".")) die_nomem();
